@@ -847,6 +847,16 @@ test('regexen', function (t) {
     false
   );
 
+  var c = /abc/g;
+  var d = /abc/i;
+  t.deepEqualTest(
+    c,
+    d,
+    'two regexes with the same source but different flags',
+    false,
+    false
+  );
+
   t.end();
 });
 
@@ -1165,5 +1175,66 @@ test('TypedArrays', { skip: !hasTypedArrays }, function (t) {
     st.end();
   });
 
+  t.test('ArrayBuffers', { skip: typeof ArrayBuffer !== 'function' }, function (st) {
+    var buffer1 = new ArrayBuffer(8); // initial value of 0's
+    var buffer2 = new ArrayBuffer(8); // initial value of 0's
+
+    var view1 = new Int8Array(buffer1);
+    var view2 = new Int8Array(buffer2);
+
+    st.deepEqualTest(
+      view1,
+      view2,
+      'Int8Arrays of similar ArrayBuffers',
+      true,
+      true
+    );
+
+    st.deepEqualTest(
+      buffer1,
+      buffer2,
+      'similar ArrayBuffers',
+      true,
+      true
+    );
+
+    for (var i = 0; i < view1.byteLength; i += 1) {
+      view1[i] = 9; // change all values to 9's
+    }
+
+    st.deepEqualTest(
+      view1,
+      view2,
+      'Int8Arrays of different ArrayBuffers',
+      false,
+      false
+    );
+
+    st.deepEqualTest(
+      buffer1,
+      buffer2,
+      'different ArrayBuffers',
+      false,
+      false
+    );
+
+    t.test('lies about byteLength', { skip: !('byteLength' in ArrayBuffer.prototype) }, function (s2t) {
+      var empty4 = new ArrayBuffer(4);
+      var empty6 = new ArrayBuffer(6);
+      Object.defineProperty(empty6, 'byteLength', { value: 4 });
+
+      s2t.deepEqualTest(
+        empty4,
+        empty6,
+        'different-length ArrayBuffers, one lying',
+        false,
+        false
+      );
+      s2t.end();
+    });
+
+    st.end();
+  });
+
   t.end();
 });
